@@ -1,10 +1,8 @@
 from __future__ import annotations
 
-import functools
 import logging
 import threading
 import warnings
-import weakref
 from typing import TYPE_CHECKING, Optional, Protocol, Tuple, Type, TypedDict, Union
 
 import numpy as np
@@ -32,23 +30,12 @@ def _curthread():
     return threading.current_thread().name
 
 
-def log_event(topic: str, msg: dict) -> None:
-    try:
-        import distributed
-
-        worker = distributed.get_worker()
-    except (ImportError, ValueError):
-        return
-    worker.log_event(topic, dict(msg, thread=_curthread()))
-
-
 # /TODO
 
 
 # Default GDAL configuration options
 DEFAULT_GDAL_ENV = LayeredEnv(
     always=dict(
-        CPL_VSIL_CURL_ALLOWED_EXTENSIONS="tif",  # don't really know what this does. may not be necessary/desireable
         GDAL_HTTP_MULTIRANGE="YES",  # unclear if this actually works
         GDAL_HTTP_MERGE_CONSECUTIVE_RANGES="YES",
         # ^ unclear if this works either. won't do much when our dask chunks are aligned to the dataset's chunks.
@@ -204,8 +191,6 @@ class ThreadLocalRioDataset:
         # but because `close` closes datasets across all threads by simply deleting the current threadlocal
         # and replacing it with an empty one, we have to synchronize all access to `self._threadlocal`.
 
-        log_event("create_ThreadLocalRioDataset", dict(url=self._url, vrt=bool(vrt)))
-
     def _open(self) -> Union[SelfCleaningDatasetReader, WarpedVRT]:
         with self._env.open:
             with time(f"Reopen {self._url!r} in {_curthread()}: {{t}}"):
@@ -215,11 +200,9 @@ class ThreadLocalRioDataset:
                     driver=self._driver,
                     **self._open_options,
                 )
-                log_event("open_dataset", dict(url=self._url))
             if self._vrt_params:
                 with self._env.open_vrt:
                     result = vrt = WarpedVRT(ds, sharing=False, **self._vrt_params)
-                    log_event("open_vrt", dict(url=self._url))
             else:
                 vrt = None
 
@@ -227,11 +210,6 @@ class ThreadLocalRioDataset:
             self._threadlocal.ds = ds
             self._threadlocal.vrt = vrt
 
-        weakref.ref(
-            ds, functools.partial(log_event, "close_dataset", dict(url=self._url))
-        )
-        weakref.ref(vrt, functools.partial(log_event, "close_vrt", dict(url=self._url)))
-        # NOTE: functools.partial to hopefully avoid taking a closure over `self`
         return result
 
     @property
@@ -278,7 +256,6 @@ class ThreadLocalRioDataset:
         # datasets.
         # NOTE: we're assuming here that closing a GDAL dataset from a thread other than the one that created
         # it is safe to do, which, knowing GDAL, is quite possibly untrue.
-        log_event("close_ThreadLocalRioDataset", dict(url=self._url))
         with self._lock:
             self._threadlocal = threading.local()
 
@@ -302,7 +279,7 @@ class PickleState(TypedDict):
     spec: RasterSpec
     resampling: Resampling
     dtype: np.dtype
-    fill_value: Optional[Union[int, float]]
+    fill_value: Union[int, float]
     rescale: bool
     gdal_env: Optional[LayeredEnv]
     errors_as_nodata: Tuple[Exception, ...]
@@ -325,7 +302,7 @@ class AutoParallelRioReader:
         spec: RasterSpec,
         resampling: Resampling,
         dtype: np.dtype,
-        fill_value: Optional[Union[int, float]],
+        fill_value: Union[int, float],
         rescale: bool,
         gdal_env: Optional[LayeredEnv] = None,
         errors_as_nodata: Tuple[Exception, ...] = (),
@@ -366,14 +343,6 @@ class AutoParallelRioReader:
                     "a separate STAC asset), so you'll need to exclude this asset from your analysis."
                 )
 
-            log_event("open_dataset_initial", dict(url=self.url))
-            weakref.ref(
-                ds,
-                functools.partial(
-                    log_event, "close_dataset_initial", dict(url=self.url)
-                ),
-            )
-
             # Only make a VRT if the dataset doesn't match the spatial spec we want
             if self.spec.vrt_params != {
                 "crs": ds.crs.to_epsg(),
@@ -388,13 +357,6 @@ class AutoParallelRioReader:
                         resampling=self.resampling,
                         **self.spec.vrt_params,
                     )
-                    log_event("open_vrt_initial", dict(url=self.url))
-                    weakref.ref(
-                        vrt,
-                        functools.partial(
-                            log_event, "close_vrt_initial", dict(url=self.url)
-                        ),
-                    )
             else:
                 logger.info(f"Skipping VRT for {self.url!r}")
                 vrt = None
@@ -445,8 +407,6 @@ class AutoParallelRioReader:
 
         result = result.astype(self.dtype, copy=False)
         result = np.ma.filled(result, fill_value=self.fill_value)
-        # ^ NOTE: if `self.fill_value` was None, rasterio set the masked array's fill value to the
-        # nodata value of the band, which `np.ma.filled` will then use.
         return result
 
     def close(self) -> None:
