@@ -629,7 +629,7 @@ class MapObserver:
     def base_url_from_window_location(url: str) -> Optional[str]:
         if not url:
             return None
-        if path_re := re.match(r"(^.+)\/(?:lab|notebook|voila)", url):
+        if path_re := re.match(r"(^.+?)\/(?:lab|notebook|voila)", url):
             return path_re.group(1)
         return None
 
@@ -854,7 +854,7 @@ def _launch_server() -> asyncio.AbstractEventLoop:
 
             while True:
                 try:
-                    site = web.TCPSite(runner, "localhost", PORT)
+                    site = web.TCPSite(runner, "127.0.0.1", PORT)
                     await site.start()
                 except OSError as e:
                     if e.errno != errno.EADDRINUSE:
